"use strict";

var full = location.protocol+'//'+location.hostname+(location.port ? ':'+location.port: '');
var plugin_folder = full + '/wp-content/plugins/voiser';

//İlk açılışta çalıştırılacak fonksiyonlar
jQuery(document).ready(function () {
    insertSettings();
    getVoices();
    $('.select2').select2({
        width:"100%",
        theme: "bootstrap"
    });
    triggerRangeInput();

    Coloris({
        el: '.coloris',
        swatches: [
            '#264653',
            '#2a9d8f',
            '#e9c46a',
            '#f4a261',
            '#e76f51',
            '#d62828',
            '#023e8a',
            '#0077b6',
            '#0096c7',
            '#00b4d8',
            '#48cae4'
        ]
    });

    createPieChart();
});

function insertSettings() {
    $("#voiser_body #settings-form").on("submit", function (event) {
        event.preventDefault();
        var form = $(this);
        $.ajax({
            type: form.attr('method'),
            url: form.attr('action'),
            data: form.serialize(),
            success : function(result) {
                var obj = JSON.parse(result);
                if (obj.status == "1") {

                    toastr.success(obj.message, obj.message_title, {
                        showMethod: "fadeIn",
                        hideMethod: "fadeOut",
                        timeOut: 2e3
                    })

                } else if(obj.status == "2"){

                    toastr.warning(obj.message, obj.message_title, {
                        showMethod: "fadeIn",
                        hideMethod: "fadeOut",
                        timeOut: 2e3
                    })

                } else{

                    toastr.error(obj.message, obj.message_title, {
                        showMethod: "fadeIn",
                        hideMethod: "fadeOut",
                        timeOut: 2e3
                    })

                }
            }
        });
    });
};

function getVoices(){
    $("#voiser_body #voiser_language_list").on("change", function (event) {

        var language = $(this).val();
        var selected = $("#voiser_body #voiser_voice_list").attr("data-selected");

        event.preventDefault();

        $.ajax({
            url: "https://voiser.net/api/wordpress/voice-list.php",
            type:"POST",
            data:{language:language, selected:selected, lang:$("#voiser_body #voiser_voice_list").attr('data-lang')},
            success:function(result)
            {
                var obj = JSON.parse(result);

                if(obj.status == '1'){

                    $('#voiser_body #voiser_voice_list').empty().trigger("change");
                    $("#voiser_body #voiser_voice_list").html(obj.data);

                } else if(obj.status == "0"){

                    toastr.error(obj.message, obj.message_title, {
                        showMethod: "fadeIn",
                        hideMethod: "fadeOut",
                        timeOut: 2e3
                    })

                }

            }
        })

    })
}

function createPieChart() {
    $('.easy-pie-chart').each(function () {
        var $elem = $(this),
            pieChartSize = $elem.attr('data-size') || "160",
            pieChartAnimate = $elem.attr('data-animate') || "2000",
            pieChartWidth = $elem.attr('data-width') || "6",
            pieChartColor = $elem.attr('data-color') || "#84ba3f",
            pieChartText = $elem.attr('data-text') || "100",
            pieChartPercent = $elem.attr('data-percent') || "100",
            pieChartTrackColor = $elem.attr('data-trackcolor') || "rgba(0,0,0,0.10)";

        $elem.find('span, i').css({
            'width': pieChartSize + 'px',
            'height': pieChartSize + 'px',
            'line-height': pieChartSize + 'px'
        });

        $elem.easyPieChart({
            size: Number(pieChartSize),
            animate: Number(pieChartAnimate),
            trackColor: pieChartTrackColor,
            lineWidth: Number(pieChartWidth),
            barColor: pieChartColor,
            scaleColor: false,
            lineCap: 'square',
            onStep: function (from, to, percent) {
                if (pieChartText==0) {
                    $elem.find('span.percent').text("0");
                } else {
                    $elem.find('span.percent').text(Math.round(pieChartText / pieChartPercent * percent));
                }
            }
        });
    });
}

function triggerRangeInput() {
    $('#voiser_body .custom-range').on('input',function () {
        var val = $(this).val();
        var input = $(this).attr('data-input');
        $('#voiser_body #'+input).val(val);
    });
    $('#voiser_body .custom-range-input').on('keyup change',function () {
        var val = $(this).val();
        var range = $(this).attr('data-range');

        if (val > $('#voiser_body #'+range).attr('max')){
            val = $('#voiser_body #'+range).attr('max');
            $(this).val(val);
        }
        if(val < $('#voiser_body #'+range).attr('min')){
            val = $('#voiser_body #'+range).attr('min');
            $(this).val(val);
        }
        $('#voiser_body #'+range).val(val);
    });
}